CGameManiaPlanet@ appMP;
CGameManiaPlanetScriptAPI@ scriptAPI;

void Main() {
	@appMP = cast<CGameManiaPlanet>(GetApp());
	@scriptAPI = appMP.ManiaPlanetScriptAPI;	

	while (true) {
		sleep(Setting_CheckInterval);
		if (!Setting_Enabled || IsSettingsPageActive()) { // Don't override settings page changes while open
			continue;
		}

		scriptAPI.DisplaySettings_LoadCurrent();
		if(ShouldApplyDisplayMode()) {
			ApplyTargetDisplayMode();
		}

// TODO: Remove preprocessor directive when IsSettingsPageActive is implemented for ManiaPlanet.
#if TMNEXT
		scriptAPI.DisplaySettings_Unload();
#endif
	}
}

void RenderMenu() 
{
	if (UI::MenuItem(Icons::Desktop + " Force Display Mode", "", Setting_Enabled)) {
		Setting_Enabled = !Setting_Enabled;
	}
}



bool IsSettingsPageActive() {
#if TMNEXT
	// In TM2020, Nadeo settings pages load and unload the settings object upon opening and closing.
	// Therefore when DisplaySettings are set, a settings page should be active.
	// (Or some other plugin loaded them and did not unload them, which would be unfortunate)
	return scriptAPI.DisplaySettings !is null;
#else
	// TODO: Above mentioned behaviour is not true for ManiaPlanet.
	// ManiaPlanet loads settings once on startup, but they are not kept up to date.
	// Closing the settings page will also not unload the settings.
	return false;
#endif
}

bool ShouldApplyDisplayMode() {
	CGameDisplaySettingsWrapper::EDisplayMode currentDisplayMode = scriptAPI.DisplaySettings.DisplayMode;
	return currentDisplayMode != Setting_TargetDisplayMode	// If we're in the wrong display mode but
			&& appMP.InputPort.IsFocused; 					// only when the game is focused
}

void ApplyTargetDisplayMode() {
	print("Applying target display mode");
	scriptAPI.DisplaySettings.DisplayMode = Setting_TargetDisplayMode;
	scriptAPI.DisplaySettings_Apply();
	if(Setting_ShowNotification) {
		UI::ShowNotification("Force Display Mode", "Display mode changed", Setting_NotificationDuration);
	}
}